@@ -13,9 +13,10 @@
 ##############################################################################
 import doctest
 
+
 def test_suite():
     return doctest.DocFileSuite(
         'README.txt',
-        optionflags=doctest.NORMALIZE_WHITESPACE|\
-                    doctest.ELLIPSIS|\
-                    doctest.IGNORE_EXCEPTION_DETAIL)
+        optionflags=(doctest.NORMALIZE_WHITESPACE
+                     | doctest.ELLIPSIS
+                     | doctest.IGNORE_EXCEPTION_DETAIL))
